package com.phm.manage.service.impl;

import com.phm.manage.domain.SoftwareConfig;
import com.phm.manage.mapper.SoftwareConfigMapper;
import com.phm.manage.service.ISoftwareConfigService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 软件配置库信息Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class SoftwareConfigServiceImpl implements ISoftwareConfigService {
    @Autowired
    private SoftwareConfigMapper softwareConfigMapper;

    /**
     * 查询软件配置库信息
     *
     * @param id 软件配置库信息主键
     * @return 软件配置库信息
     */
    @Override
    public SoftwareConfig selectSoftwareConfigById(Long id) {
        return softwareConfigMapper.selectSoftwareConfigById(id);
    }

    /**
     * 查询软件配置库信息列表
     *
     * @param softwareConfig 软件配置库信息
     * @return 软件配置库信息
     */
    @Override
    public List<SoftwareConfig> selectSoftwareConfigList(SoftwareConfig softwareConfig) {
        return softwareConfigMapper.selectSoftwareConfigList(softwareConfig);
    }

    /**
     * 新增软件配置库信息
     *
     * @param softwareConfig 软件配置库信息
     * @return 结果
     */
    @Override
    public int insertSoftwareConfig(SoftwareConfig softwareConfig) {
        return softwareConfigMapper.insertSoftwareConfig(softwareConfig);
    }

    /**
     * 修改软件配置库信息
     *
     * @param softwareConfig 软件配置库信息
     * @return 结果
     */
    @Override
    public int updateSoftwareConfig(SoftwareConfig softwareConfig) {
        return softwareConfigMapper.updateSoftwareConfig(softwareConfig);
    }

    /**
     * 批量删除软件配置库信息
     *
     * @param ids 需要删除的软件配置库信息主键
     * @return 结果
     */
    @Override
    public int deleteSoftwareConfigByIds(Long[] ids) {
        return softwareConfigMapper.deleteSoftwareConfigByIds(ids);
    }

    /**
     * 删除软件配置库信息信息
     *
     * @param id 软件配置库信息主键
     * @return 结果
     */
    @Override
    public int deleteSoftwareConfigById(Long id) {
        return softwareConfigMapper.deleteSoftwareConfigById(id);
    }
}
